@@ -1,21 +1,14 @@
 from rest_framework.viewsets import GenericViewSet
 from ..paginations import DefaultPagination
 from .mixins import CreateMixin, RetrieveMixin, UpdateMixin, ListMixin, DestroyMixin
-
+from ..exceptions.apis import AuthenticationFailedExp, PemissionDeniedExp
 
 class BaseViewSet(GenericViewSet, CreateMixin, RetrieveMixin, UpdateMixin, ListMixin, DestroyMixin):
     serializer_action_classes = {}
     permission_action_classes = {}
     page_size = 10
-    page_result_key = None
     pagination_class = DefaultPagination
 
-    def _get_request_access_token(self, request):
-        current_token = request.headers.get('Authorization', None)
-        if current_token != None:
-            current_token = current_token.split(' ')[1]
-        return current_token
-
     def get_serializer_class(self, *args, **kwargs):
         try:
             if self.action == 'list':
@@ -41,7 +34,7 @@ class BaseViewSet(GenericViewSet, CreateMixin, RetrieveMixin, UpdateMixin, ListM
             else:
                 self._paginator = self.pagination_class()
                 self._paginator.page_size = self.page_size
-                self._paginator.page_result_key = self.page_result_key
+                self._paginator.page_result_key = self.queryset.model._meta.verbose_name_plural
         return self._paginator
 
     def get_queryset(self):
@@ -50,3 +43,9 @@ class BaseViewSet(GenericViewSet, CreateMixin, RetrieveMixin, UpdateMixin, ListM
             return qs
         else:
             return super().get_queryset()
+
+    def permission_denied(self, request, message=None, code=None):
+        if request.authenticators and not request.successful_authenticator:
+            raise AuthenticationFailedExp('Unauthenticated')
+        raise PemissionDeniedExp('Permission Denied')
+
